package com.sun.rowset.internal;

import java.io.ObjectInputStream;
import javax.sql.RowSetInternal;
import java.io.InputStream;
import org.xml.sax.XMLReader;
import javax.xml.parsers.SAXParser;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import java.sql.SQLException;
import java.text.MessageFormat;
import javax.xml.parsers.SAXParserFactory;
import org.xml.sax.InputSource;
import java.io.Reader;
import javax.sql.rowset.WebRowSet;
import java.io.IOException;
import com.sun.rowset.JdbcRowSetResourceBundle;
import java.io.Serializable;
import javax.sql.rowset.spi.XmlReader;

public class WebRowSetXmlReader implements XmlReader, Serializable
{
    private JdbcRowSetResourceBundle resBundle;
    static final long serialVersionUID = -9127058392819008014L;
    
    public WebRowSetXmlReader() {
        try {
            this.resBundle = JdbcRowSetResourceBundle.getJdbcRowSetResourceBundle();
        }
        catch (IOException cause) {
            throw new RuntimeException(cause);
        }
    }
    
    @Override
    public void readXML(WebRowSet set, Reader characterStream) throws SQLException {
        try {
            InputSource inputSource = new InputSource(characterStream);
            XmlErrorHandler errorHandler = new XmlErrorHandler();
            XmlReaderContentHandler contentHandler = new XmlReaderContentHandler(set);
            SAXParserFactory instance = SAXParserFactory.newInstance();
            instance.setNamespaceAware(true);
            instance.setValidating(true);
            SAXParser saxParser = instance.newSAXParser();
            saxParser.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://www.w3.org/2001/XMLSchema");
            XMLReader xmlReader = saxParser.getXMLReader();
            xmlReader.setEntityResolver(new XmlResolver());
            xmlReader.setContentHandler(contentHandler);
            xmlReader.setErrorHandler(errorHandler);
            xmlReader.parse(inputSource);
        }
        catch (SAXParseException ex) {
            System.out.println(MessageFormat.format(this.resBundle.handleGetObject("wrsxmlreader.parseerr").toString(), new Object[] { ex.getMessage(), Integer.valueOf(ex.getLineNumber()), ex.getSystemId() }));
            ex.printStackTrace();
            throw new SQLException(ex.getMessage());
        }
        catch (SAXException exception) {
            if (exception.getException() != null) {
                exception = exception.getException();
            }
            exception.printStackTrace();
            throw new SQLException(exception.getMessage());
        }
        catch (ArrayIndexOutOfBoundsException ex2) {
            throw new SQLException(this.resBundle.handleGetObject("wrsxmlreader.invalidcp").toString());
        }
        catch (Throwable t) {
            throw new SQLException(MessageFormat.format(this.resBundle.handleGetObject("wrsxmlreader.readxml").toString(), new Object[] { t.getMessage() }));
        }
    }
    
    public void readXML(WebRowSet set, InputStream byteStream) throws SQLException {
        try {
            InputSource inputSource = new InputSource(byteStream);
            XmlErrorHandler errorHandler = new XmlErrorHandler();
            XmlReaderContentHandler contentHandler = new XmlReaderContentHandler(set);
            SAXParserFactory instance = SAXParserFactory.newInstance();
            instance.setNamespaceAware(true);
            instance.setValidating(true);
            SAXParser saxParser = instance.newSAXParser();
            saxParser.setProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage", "http://www.w3.org/2001/XMLSchema");
            XMLReader xmlReader = saxParser.getXMLReader();
            xmlReader.setEntityResolver(new XmlResolver());
            xmlReader.setContentHandler(contentHandler);
            xmlReader.setErrorHandler(errorHandler);
            xmlReader.parse(inputSource);
        }
        catch (SAXParseException ex) {
            System.out.println(MessageFormat.format(this.resBundle.handleGetObject("wrsxmlreader.parseerr").toString(), new Object[] { Integer.valueOf(ex.getLineNumber()), ex.getSystemId() }));
            System.out.println("   " + ex.getMessage());
            ex.printStackTrace();
            throw new SQLException(ex.getMessage());
        }
        catch (SAXException exception) {
            if (exception.getException() != null) {
                exception = exception.getException();
            }
            exception.printStackTrace();
            throw new SQLException(exception.getMessage());
        }
        catch (ArrayIndexOutOfBoundsException ex2) {
            throw new SQLException(this.resBundle.handleGetObject("wrsxmlreader.invalidcp").toString());
        }
        catch (Throwable t) {
            throw new SQLException(MessageFormat.format(this.resBundle.handleGetObject("wrsxmlreader.readxml").toString(), new Object[] { t.getMessage() }));
        }
    }
    
    @Override
    public void readData(RowSetInternal rowSetInternal) {
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        try {
            this.resBundle = JdbcRowSetResourceBundle.getJdbcRowSetResourceBundle();
        }
        catch (IOException cause) {
            throw new RuntimeException(cause);
        }
    }
}
